==> plugin.video.rtvs.sk-1.9.9.zip: plugin.video.rtvs.sk-master/README.md <==
Kodi plugin pre prehrávanie RTVS - rtvs.sk
- jednoduhé a prehľadné prehrávanie archívu a živého vysielania
 
![Snímka obrazovky_2024-04-30_16-25-51](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/43243367-dc64-4c33-97ce-d0069054df33)

Plugin umožňuje:
- prehrávanie živého vysielania televýznych rtvs staníc
- prehrávanie živého vysielania rádiových rtvs staníc
- archív televíznych staníc:
  - podľa abecedy
  - podľa dátumu
- archív rozhlasových staníc:
  - podľa abecedy
  - podľa dátumu
- archív extra rozhlasových staníc

podľa dátumu - dátumy sú vždy po mesiaci, preto sa treba preklikať k danému dátumu a nie sú naraz zobrazené (podobne ako na webe)

RTVS ponuka:

![Snímka obrazovky_2024-04-30_16-02-12](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/9cb52e8d-b963-4d7e-a74a-ee2d49b020b0)

Live TV + Rádio:

![Snímka obrazovky_2024-04-30_16-07-02](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/db3b806c-5ad6-4326-a81c-3a8bb6424725)

Zoznam podľa dátumu:

![Snímka obrazovky_2024-04-30_16-02-34](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/dd0fb3e1-bd3b-439a-93d7-1a46dd1268de)

Zoznam relácií podľa abecedy:

![Snímka obrazovky_2024-04-30_16-03-29](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/f05bd25c-44ac-46c1-b0b8-29758df52c8b)

Archív relácie podľa dátumu:

![Snímka obrazovky_2024-04-30_16-04-06](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/b05c5fef-4fdd-4d8e-ba61-5a3c4856b4f0)

Video info:

![Snímka obrazovky_2024-04-30_16-04-41](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/b194b0ef-d2cc-48ee-b14c-edf413232deb)

Video:

![Snímka obrazovky_2024-04-30_16-05-37](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/28cb0758-8d9c-4143-9a8e-2283e7316a7f)

_Changelog by jastrab:_ 

**1.9.9:**
- add readme.md
- upd code

**1.9.8:**
- fix video archive Date
  
**1.9.7:**
- fix version script.module.stream.resolver
  
**1.9.6:**
- add support Kodi 20
  
**1.9.5:**
- fix video archive Date
  
**1.9.4:**
- added radio archive Extra
- added radio archive Plus
  
**1.9.3:**
- added radio live
- added radio archive
- added support Kodi 18
  
**1.9.2:**
- added RTVS Sport
- added info and img to Live
- fixed archive by Date and 
- added descriptions archive by Date
- fixed settings menu


Verzia od predošlého autora doplnku:
**1.9.0**:
- Kodi 19 Matrix update

ďalšie podrobnosti v changelog súbore

==> plugin.video.rtvs.sk-1.9.11.zip: plugin.video.rtvs.sk-master/README.md <==
Kodi plugin pre prehrávanie RTVS - rtvs.sk
- jednoduhé a prehľadné prehrávanie archívu a živého vysielania
 
![Snímka obrazovky_2024-04-30_16-25-51](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/43243367-dc64-4c33-97ce-d0069054df33)

Plugin umožňuje:
- prehrávanie živého vysielania televýznych rtvs staníc
- prehrávanie živého vysielania rádiových rtvs staníc
- archív televíznych staníc:
  - podľa abecedy
  - podľa dátumu
- archív rozhlasových staníc:
  - podľa abecedy
  - podľa dátumu
- archív extra rozhlasových staníc

podľa dátumu - dátumy sú vždy po mesiaci, preto sa treba preklikať k danému dátumu a nie sú naraz zobrazené (podobne ako na webe)


Ak niečo nefunguje treba si to overiť na webe stvr.sk:
- niektoré videá skončia s hláškou "Je nám ľúto, ale toto video už nie je k dispozícii z licenčných dôvodov."
- niektoré relácie v rádiu nemajú zvukový záznam resp. majú iba text.

---

RTVS ponuka:

![Snímka obrazovky_2024-04-30_16-02-12](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/9cb52e8d-b963-4d7e-a74a-ee2d49b020b0)

Live TV + Rádio:

![Snímka obrazovky_2024-04-30_16-07-02](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/db3b806c-5ad6-4326-a81c-3a8bb6424725)

Zoznam podľa dátumu:

![Snímka obrazovky_2024-04-30_16-02-34](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/dd0fb3e1-bd3b-439a-93d7-1a46dd1268de)

Zoznam relácií podľa abecedy:

![Snímka obrazovky_2024-04-30_16-03-29](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/f05bd25c-44ac-46c1-b0b8-29758df52c8b)

Archív relácie podľa dátumu:

![Snímka obrazovky_2024-04-30_16-04-06](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/b05c5fef-4fdd-4d8e-ba61-5a3c4856b4f0)

Video info:

![Snímka obrazovky_2024-04-30_16-04-41](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/b194b0ef-d2cc-48ee-b14c-edf413232deb)

Video:

![Snímka obrazovky_2024-04-30_16-05-37](https://github.com/jastrab/plugin.video.rtvs.sk/assets/6190406/28cb0758-8d9c-4143-9a8e-2283e7316a7f)

_Changelog by jastrab:_ 

**1.9.11:**
- upd hostname
- fix urls
- fix tv 24 live name
- fix radio archive A-Z
- fix radio extra archive vzdelavanie

**1.9.10:**
- fix calendar in A-Z tv archive

**1.9.9:**
- add readme.md
- upd code

**1.9.8:**
- fix video archive Date
  
**1.9.7:**
- fix version script.module.stream.resolver
  
**1.9.6:**
- add support Kodi 20
  
**1.9.5:**
- fix video archive Date
  
**1.9.4:**
- added radio archive Extra
- added radio archive Plus
  
**1.9.3:**
- added radio live
- added radio archive
- added support Kodi 18
  
**1.9.2:**
- added RTVS Sport
- added info and img to Live
- fixed archive by Date and 
- added descriptions archive by Date
- fixed settings menu


Verzia od predošlého autora doplnku:
**1.9.0**:
- Kodi 19 Matrix update

ďalšie podrobnosti v changelog súbore
